@@ -1,6 +1,6 @@
 package Proc::tored::Role::Running;
 # ABSTRACT: add running state and signal handling to services
-$Proc::tored::Role::Running::VERSION = '0.02';
+$Proc::tored::Role::Running::VERSION = '0.03';
 use strict;
 use warnings;
 use Moo::Role;
@@ -8,6 +8,8 @@ use Types::Standard -types;
 use Time::HiRes 'sleep';
 use Guard 'guard';
 
+my @SIGNALS = qw(TERM INT PIPE HUP);
+
 =head1 NAME
 
 Proc::tored::Role::Running
@@ -38,47 +40,6 @@ calling L</stop_running_process>), the class will voluntarily L</stop> itself.
 
 =head1 ATTRIBUTES
 
-=head2 poll_wait_time
-
-Optionally specifies the length of time (in fractional seconds) during which
-the process will sleep when calling L</stop_running_service> with a C<timeout>.
-Defaults to 0.2 seconds.
-
-=cut
-
-has poll_wait_time => (
-  is  => 'ro',
-  isa => Num,
-  default => 0.2,
-);
-
-=head2 is_running
-
-Returns true while the service is running in the current process.
-
-=cut
-
-has is_running => (
-  is  => 'ro',
-  isa => Bool,
-  default => 0,
-  init_arg => undef,
-);
-
-=head2 signal_handler
-
-Used internally to store the previously set signal handlers while
-L</is_running> is true.
-
-=cut
-
-has signal_handler => (
-  is  => 'ro',
-  isa => Map[Str, CodeRef],
-  default => sub { {} },
-  init_arg => undef,
-);
-
 =head2 run_guard
 
 A Guard used to ensure signal handlers are restored when the object is destroyed.
@@ -93,6 +54,14 @@ has run_guard => (
 
 =head1 METHODS
 
+=head2 is_running
+
+Returns true while the service is running in the current process.
+
+=cut
+
+sub is_running { defined $_[0]->run_guard ? 1 : 0 }
+
 =head2 start
 
 Flags the current process as I<running>. While running, handlers for
@@ -101,36 +70,25 @@ this method, L</is_running> will return true.
 
 =cut
 
-sub _build_signal_handler {
-  my ($self, $signal) = @_;
-
-  sub {
-    $self->{is_running} = 0; # redundant, but an existing sigterm handler may inspect it
-    $self->signal_handler->{$signal}->(@_)
-      if $self->signal_handler->{$signal};
-    $self->stop;
-  };
-}
-
 sub start {
   my $self = shift;
-  $self->{is_running} = 1;
-
   my %sig = %SIG;
-  my @signals = qw(TERM INT PIPE HUP);
-  my @existing = grep { $sig{$_} } @signals;
+  my @existing = grep { $sig{$_} } @SIGNALS;
 
-  $self->{signal_handler} = \%sig;
-
-  $SIG{$_} = $self->_build_signal_handler($_)
-    foreach @signals;
+  foreach my $signal (@SIGNALS) {
+    $SIG{$signal} = sub {
+      $sig{$signal} && $sig{$signal}->(@_);
+      $self->stop;
+    };
+  }
 
   $self->{run_guard} = guard {
-    undef $SIG{$_} foreach @signals; # remove our handlers
+    undef $SIG{$_} foreach @SIGNALS; # remove our handlers
     $SIG{$_} = $sig{$_} foreach @existing; # restore original handlers
+    undef %sig;
   };
 
-  return 1;
+  $self->is_running;
 }
 
 =head2 stop
@@ -141,13 +99,7 @@ will return false.
 
 =cut
 
-sub stop {
-  my $self = shift;
-  $self->{is_running} = 0;
-  undef $self->{run_guard};
-  $self->{signal_handler} = {};
-  return 1;
-}
+sub stop { undef $_[0]->{run_guard}; !$_[0]->is_running; }
 
 =head2 stop_running_process
 
@@ -163,23 +115,21 @@ Returns the pid of the completed process otherwise.
 
 =cut
 
-sub _alive { kill(0, $_[0]) > 0 }
-
 sub stop_running_process {
-  my ($self, $pid, $timeout) = @_;
-  my $sleep = $self->poll_wait_time;
+  my ($self, $pid, $timeout, $sleep) = @_;
   return 0 unless $pid;
+  $sleep ||= 0.2;
 
-  if (kill('SIGTERM', $pid) > 0) {
+  if (kill('TERM', $pid) > 0) {
     if ($timeout) {
-      while (_alive($pid) && $timeout > 0) {
+      while (kill(0, $pid) && $timeout > 0) {
         sleep $sleep;
         $timeout -= $sleep;
       }
     }
   }
 
-  _alive($pid) ? $pid : 0;
+  !kill(0, $pid);
 }
 
 1;
